<?php

namespace Drupal\Tests\tour_core\Functional\Language;

use Drupal\Tests\tour_core\Functional\TourTestBase;

/**
 * Tests tour functionality.
 *
 * @group tour
 */
class LanguageTourTest extends TourTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'block',
    'language',
    'content_translation',
    'tour',
  ];

  /**
   * {@inheritdoc}
   */
  protected array $permissions = ['administer content translation', 'administer languages'];

  /**
   * Tests various language URLs for tours.
   */
  public function testVariousLanguageTours(): void {
    $this->testLanguageTour();
    $this->testLanguageAddTour();
    $this->testLanguageEditTour();
    $this->testContentLanguageSettingsTour();
  }

  /**
   * Tests language tour tip availability.
   */
  protected function testLanguageTour(): void {
    $this->drupalGet('admin/config/regional/language');
    $this->assertTourTips();
  }

  /**
   * Go to add language page and check the tour tooltips.
   */
  protected function testLanguageAddTour(): void {
    $this->drupalGet('admin/config/regional/language/add');
    $this->assertTourTips();
  }

  /**
   * Go to edit language page and check the tour tooltips.
   */
  protected function testLanguageEditTour(): void {
    $this->drupalGet('admin/config/regional/language/edit/en');
    $this->assertTourTips();
  }

  /**
   * Go to edit language page and check the tour tooltips.
   */
  protected function testContentLanguageSettingsTour(): void {
    $this->drupalGet('admin/config/regional/content-language');
    $this->assertTourTips();
  }

}
